Read-only mirrors. Development, issues and pull requests are on GitHub.

summaryrefslogtreecommitdiffhomepage
path: root/docs/release-notes.md
diff options
context:
space:
mode:
authorMartin Hořeňovský2026-07-26 22:19:31 +0200
committerMartin Hořeňovský2026-07-26 22:19:31 +0200
commit8b08d4d79514f45f7e4ce2a607ac9c94e920d1bb (patch)
tree6ae81663dc4ea2fd5024129daf8d3187ec1433a6 /docs/release-notes.md
parent1079da4c5f5fea2a31d795bba95eacaa2f622849 (diff)
downloadcatch3-3.15.3.tar.gz
v3.15.3v3.15.3
Diffstat (limited to 'docs/release-notes.md')
-rw-r--r--docs/release-notes.md23
1 files changed, 23 insertions, 0 deletions
diff --git a/docs/release-notes.md b/docs/release-notes.md
index ffa06430..9fafa0cd 100644
--- a/docs/release-notes.md
+++ b/docs/release-notes.md
@@ -2,6 +2,7 @@
# Release notes
**Contents**<br>
+[3.15.3](#3153)<br>
[3.15.2](#3152)<br>
[3.15.1](#3151)<br>
[3.15.0](#3150)<br>
@@ -77,6 +78,28 @@
[Even Older versions](#even-older-versions)<br>
+
+## 3.15.3
+
+### Fixes
+* The JSON reporter's number handling is locale-independent. (#3176)
+* Removed leftover debug message from `catch_discover_tests` (#3177)
+* Fixed typo in the "Could not jump to the Nth element" exception message (#3181)
+
+### Improvements
+* `catch_discover_tests` registers tests in deterministic (alphabetical) order.
+* `catch_discover_tests` has been rewritten to be massively faster.
+ * Preparing the actual CTest script is significantly faster.
+ * Parsing the JSON test array is significantly faster.
+ * Running without `ADD_TAGS_AS_LABELS` set is 10-15% faster (as opposed to being the same speed) (#3169)
+ * The new implementation is about 4x-5x faster, so registering 500 tests now takes ~350ms (down from 1.1s).
+* JSON writing is faster
+ * Small improvement in writing non-string values
+ * ~6-40% improvement in writing string values that do not need escaping
+ * ~1-6% improvement in writing string values that do need escaping
+* Better support for infs and NaNs in JSON output
+
+
## 3.15.2
### Fixes